@@ -131,10 +131,12 @@ if(isset($_GET['action'])) {
                 else if($rs[imei_mode]==0) $imei_ck1='selected';
                 else if($rs[imei_mode]==2) $imei_ck3='selected';
                 else if($rs[imei_mode]==3) $imei_ck4='selected';
+                else if($rs[imei_mode]==4) $imei_ck5='selected';
                 
                 if($rs[no_ring_disable]) $wa_ck1='checked';
                 if($rs[no_answer_disable]) $wa_ck2='checked';
                 if($rs[short_call_disable]) $wa_ck3='checked';
+		if($rs[count_limit_no_connect]) $ci_no_connect_ck='checked';
 
                 if($rs['remain_time']<0) $rs['remain_time'] = "";
 
@@ -164,12 +166,18 @@ if(isset($_GET['action'])) {
 		$sim_rs=$db->fetch_array($db->query("SELECT * FROM sim where sim_name='$sim_name'"));
 		if($sim_rs['time_limit']!=$_POST['time_limit']) $t_remain.=",remain_time=$_POST[time_limit]";
 		if($sim_rs['count_limit']!=$_POST['count_limit']) $t_remain.=",count_remain=$_POST[count_limit]";
+		if($sim_rs['limit_sms']!=$_POST['limit_sms']) $t_remain.=",remain_sms=$_POST[limit_sms]";
+		if($sim_rs['month_limit_time']!=$_POST['month_limit_time']) $t_remain.=",month_remain_time=$_POST[month_limit_time]";
 		if($sim_rs['no_connected_limit']!=$_POST['no_connected_limit']) $t_remain.=",no_connected_remain=$_POST[no_connected_limit]";
-		$db->query("UPDATE sim SET imei_mode='$imei_mode', sim_team_id='$team_id',dev_disable='$dev_disable',plan_line_name='$_POST[line_name]',imei='$imei',time_limit='$_POST[time_limit]',time_unit='$time_unit',no_ring_limit='$_POST[no_ring_limit]',no_answer_limit='$_POST[no_answer_limit]',short_call_limit='$_POST[short_call_limit]',short_time='$_POST[short_time]',no_ring_disable='$_POST[no_ring_disable]',no_answer_disable='$_POST[no_answer_disable]',short_call_disable='$_POST[short_call_disable]',count_limit='$_POST[count_limit]',no_connected_limit='$_POST[no_connected_limit]',auto_reset_remain='$auto_reset_remain',auto_reset_remain_s='$auto_reset_remain_s' $t_remain WHERE sim_name='$sim_name'");
+		if($dev_disable==0 && $sim_rs['dev_disable']==1) 
+			$db->query("update sim SET no_ring_remain=0,no_answer_remain=0,short_call_remain=0 where sim_name='$sim_name' and ((short_call_disable=1 and short_call_limit>0 and short_call_remain>=short_call_limit) or (no_ring_disable=1 and no_ring_limit>0 and no_ring_remain>=no_ring_limit) or (no_answer_disable=1 and no_answer_limit>0 and no_answer_remain>=no_answer_limit))");
+		$db->query("UPDATE sim SET imei_mode='$imei_mode', sim_team_id='$team_id',dev_disable='$dev_disable',plan_line_name='$_POST[line_name]',imei='$imei',time_limit='$_POST[time_limit]',time_unit='$time_unit',no_ring_limit='$_POST[no_ring_limit]',no_answer_limit='$_POST[no_answer_limit]',short_call_limit='$_POST[short_call_limit]',short_time='$_POST[short_time]',no_ring_disable='$_POST[no_ring_disable]',no_answer_disable='$_POST[no_answer_disable]',short_call_disable='$_POST[short_call_disable]',count_limit='$_POST[count_limit]',no_connected_limit='$_POST[no_connected_limit]',auto_reset_remain='$auto_reset_remain',auto_reset_remain_s='$auto_reset_remain_s',count_limit_no_connect='$_POST[count_limit_no_connect]',limit_sms='$_POST[limit_sms]',month_limit_time='$_POST[month_limit_time]',month_reset_day='$_POST[month_reset_day]' $t_remain WHERE sim_name='$sim_name'");
 
 
 		$query=$db->query("select sim.*,password from sim left join sim_bank on sim.bank_name=sim_bank.name where sim_name='$sim_name'");
 		while($row=$db->fetch_array($query)) {
+			sim_info($row, $send);
+/*
 			if($row['imei']==NULL) $row['imei'] = "000000000000000";
 			$imei_len=strlen($row['imei']);
 			if($imei_len<15) $row['imei'] = sprintf("%15s",$row['imei']."000000000000000");
@@ -187,11 +195,13 @@ if(isset($_GET['action'])) {
 				$send[]=my_pack2($row[dev_disable]?DEV_DISABLE:DEV_ENABLE, $row[sim_name], TYPE_SIM);
 			}
 			//sendto_xchanged($send);
+*/
 		}
 		//unset($send);
 		//echo DEV_BINDING;
 		if(!$team_id){
 			$send[]=my_pack2(DEV_BINDING, $sim_name, $_POST[line_name]);
+			//echo "1111111";
 		}
 		else {
 			$send[]=my_pack2(DEV_BINDING, $sim_name, 0);
@@ -225,7 +235,9 @@ if(isset($_GET['action'])) {
 		$imei_mode=$_POST['imei_mode'];
 		$where=gen_sim_where();
 		if($remain_time == "" || $remain_time < -1) $remain_time=-1;
+		if($_POST[month_limit_time] == "" || $_POST[month_limit_time] < -1) $_POST[month_limit_time]=-1;
 		if($_POST[time_limit] == "" || $_POST[time_limit] < -1) $_POST[time_limit]=-1;
+		if($_POST[limit_sms] == "" || $_POST[limit_sms] < -1) $_POST[limit_sms]=-1;
                 if($_POST[no_ring_limit] == "" || $_POST[no_ring_limit] < -1) $_POST[no_ring_limit]=-1;
                 if($_POST[no_answer_limit] == "" || $_POST[no_answer_limit] < -1) $_POST[no_answer_limit]=-1;
                 if($_POST[short_call_limit] == "" || $_POST[short_call_limit] < -1) $_POST[short_call_limit]=-1;
@@ -241,8 +253,12 @@ if(isset($_GET['action'])) {
 			$sql="UPDATE sim SET ";
 			if($_POST['team_id_modify']) $sql.="sim_team_id='$team_id',";
 			if($_POST['imei_mode_modify']) $sql.="imei_mode='$imei_mode',";
+                        if($_POST['month_limit_time_modify']) $sql.="month_limit_time='$_POST[month_limit_time]',month_remain_time='$_POST[month_limit_time]',";
+                        if($_POST['month_reset_day_modify']) $sql.="month_reset_day='$_POST[month_reset_day]',";
 			if($_POST['time_limit_modify']) $sql.="time_limit='$_POST[time_limit]',remain_time='$_POST[time_limit]',";
 			if($_POST['count_limit_modify']) $sql.="count_limit='$_POST[count_limit]',count_remain=$_POST[count_limit],";
+			if($_POST['limit_sms_modify']) $sql.="limit_sms='$_POST[limit_sms]',remain_sms='$_POST[limit_sms]',";
+			if($_POST['count_limit_no_connect_modify']) $sql.="count_limit_no_connect='$_POST[count_limit_no_connect]',";
 			if($_POST['no_connected_limit_modify']) $sql.="no_connected_limit='$_POST[no_connected_limit]',no_connected_remain=$_POST[no_connected_limit],";
 			if($_POST['time_unit_modify']) $sql.="time_unit='$time_unit',";
 			if($_POST['no_ring_modify']) $sql.="no_ring_limit='$_POST[no_ring_limit]',no_ring_disable='$_POST[no_ring_disable]',";
@@ -250,13 +266,18 @@ if(isset($_GET['action'])) {
 			if($_POST['short_call_modify']) $sql.="short_call_limit='$_POST[short_call_limit]',short_call_disable='$_POST[short_call_disable]',";
 			if($_POST['short_time_modify']) $sql.="short_time='$_POST[short_time]',";
 			if($_POST['dev_disable_modify']) $sql.="dev_disable='$dev_disable',";
-			if($_POSY['auto_reset_remain_modify']) $sql.="auto_reset_remain='$_POST[auto_reset_remain]',";
-			if($_POSY['auto_reset_remain_s_modify']) $sql.="auto_reset_remain_s='$_POST[auto_reset_remain_s]',";
+			if($_POST['auto_reset_remain_modify']) $sql.="auto_reset_remain='$_POST[auto_reset_remain]',";
+			if($_POST['auto_reset_remain_s_modify']) $sql.="auto_reset_remain_s='$_POST[auto_reset_remain_s]',";
 			$sql.="sim_login=sim_login $where";
+			if($_POST['dev_disable_modify'] && $dev_disable==0) 
+				$db->query("update sim SET no_ring_remain=0,no_answer_remain=0,short_call_remain=0 $where and dev_disable=1 and ((short_call_disable=1 and short_call_limit>0 and short_call_remain>=short_call_limit) or (no_ring_disable=1 and no_ring_limit>0 and no_ring_remain>=no_ring_limit) or (no_answer_disable=1 and no_answer_limit>0 and no_answer_remain>=no_answer_limit))");
+
 			$db->query($sql);
 
                         $query=$db->query("select sim.*,password from sim left join sim_bank on sim.bank_name=sim_bank.name $where");
 			while($row=$db->fetch_array($query)) {
+				sim_info($row, $send);
+/*
 				if($row['imei']==NULL) $row['imei'] = "000000000000000";
 				$imei_len=strlen($row['imei']);
 				if($imei_len<15) $row['imei'] = sprintf("%15s",$row['imei']."000000000000000");
@@ -264,6 +285,7 @@ if(isset($_GET['action'])) {
 				$send[]=my_pack($row, SIM_ADD);
 				if($row['imei_mode']==3) $send[]=my_pack($row, IMEI_IMSI_INFO);
 				if($_POST['dev_disable_modify']) $send[]=my_pack2($row[dev_disable]?DEV_DISABLE:DEV_ENABLE, $row[sim_name], TYPE_SIM);
+*/
 				if($_POST['team_id_modify'] && $team_id) $send[]=my_pack2(DEV_BINDING, $sim_name, 0);
 
 			}
@@ -282,16 +304,19 @@ if(isset($_GET['action'])) {
 
 		$where=gen_sim_where();
 
-		$db->query("update sim set no_ring_remain=0,no_answer_remain=0,short_call_remain=0,remain_time=time_limit,count_remain=count_limit,no_connected_remain=no_connected_limit $where");
+		$db->query("update sim set no_ring_remain=0,no_answer_remain=0,short_call_remain=0,remain_time=time_limit,remain_sms=limit_sms,count_remain=count_limit,no_connected_remain=no_connected_limit,month_remain_time=month_limit_time $where");
 
 		$query=$db->query("select sim.*,password from sim left join sim_bank on sim.bank_name=sim_bank.name $where");
 		while($row=$db->fetch_array($query)) {
+			sim_info($row, $send);
+/*
 			if($row['imei']==NULL) $row['imei'] = "000000000000000";
 			$imei_len=strlen($row['imei']);
 			if($imei_len<15) $row['imei'] = sprintf("%15s",$row['imei']."000000000000000");
 			if($row['remain_time']==NULL || $row['remain_time'] <-1 ) $row['remain_time'] = -1;
 			$send[]=my_pack($row, SIM_ADD);
 			//$send[]=my_pack2(RESET_LIMIT, $row['sim_name']);
+*/
 		}
 		//print_r($send);
 
@@ -320,13 +345,40 @@ if(isset($_GET['action'])) {
 		sendto_xchanged($send);
 		WriteSuccessMsg("<br><li>The commond is sended to Server.</li>","?bank_name=$_REQUEST[bank_name]&group_id=$_REQUEST[group_id]&order=$order_type&order_key=$order_key");
 	}
-	else $action="main";
+	else if($action=="set_imei_db"){
+		$where=gen_sim_where();
+
+		$query=$db->query("select sim.*,password from sim left join sim_bank on sim.bank_name=sim_bank.name $where");
+		$num=$db->num_rows($query);
+		$query0=$db->query("select id,imei from imei_db order by used limit $num");
+		while($row0=$db->fetch_array($query0)) {
+			$imei_db[]=$row0;
+		}
+		$i=0;
+		while($row=$db->fetch_array($query)) {
+			if($imei_db[$i]){
+				$row['imei_mode']==2;
+				$row['imei']=$imei_db[$i]['imei'];
+				$imei_db[$i]['sim_name']=$row['sim_name'];
+				$log.="<br>SIM Slot:$row[sim_name] Set IMEI:$row[imei]";
+				$send[]=my_pack($row, SIM_ADD);
+				$db->query("update imei_db set sim_name='$row[sim_name]',used=used+1,used_time=now() where id=".$imei_db[$i]['id']);
+				$db->query("update sim set imei_mode=2, imei='$row[imei]' where id=$row[id]");
+			}
+			else {
+				$log.="<br>SIM Slot:$row[sim_name] not find IMEI from database";
+			}
+			$i++;
+		}
+		sendto_xchanged($send);
+		WriteSuccessMsg("<br><li>The commond is sended to Server.$log</li>","?bank_name=$_REQUEST[bank_name]&group_id=$_REQUEST[group_id]&order=$order_type&order_key=$order_key");
+	}
+	//else $action="main";
 
 	}
 	else $action="main";
 
-	//if($_COOKIE['adminname']=="admin")	
-	if($action=="main")
+	if($action=="main"  || $action=="export")
 	{
 		$query=$db->query("SELECT * FROM system WHERE 1 ");
 		$rs=$db->fetch_array($query);
@@ -371,6 +423,9 @@ if(isset($_GET['action'])) {
 		$fenye=showpage2("?bank_name=$_GET[bank_name]&group_id=$_GET[group_id]&order_key=$order_key&order=$order&",$page,$count,$perpage,true,true,"编","myform","boxs");
 		if($order_key) $orderby=" ORDER BY `$order_key` $order_type,sim.sim_name ";
 		else $orderby=" ORDER BY sim.sim_name ";
+		if($action=="export"){
+			export_sim($where, $orderby);
+		}     
 		$query=$db->query("SELECT sim.*,sim_team.sim_team_name,sim.line_name FROM sim left join sim_team on sim.sim_team_id=sim_team.sim_team_id left join device_line on device_line.line_name=sim.line_name $where $orderby LIMIT $start_limit,$perpage");
 		while($row=$db->fetch_array($query)) {
 			if($row['sim_login'] == 0 || $row['sim_login'] == 12){
@@ -412,22 +467,27 @@ if(isset($_GET['action'])) {
 			
 			if($row['imei_mode']==1) $row['imei_type_name']="Random";
 			else if($row['imei_mode']==0) $row['imei_type_name']="GoIP default";
-			else if($row['imei_mode']==2) $row['imei_type_name']="Set with SIM";
+			else if($row['imei_mode']==2) $row['imei_type_name']="Set with SIM Slot";
+			else if($row['imei_mode']==3) $row['imei_type_name']="Random with IMSI";
+			else if($row['imei_mode']==4) $row['imei_type_name']="Database with IMSI";
 			$row['remain_limit']="total remain time: ".$row['remain_time']."/".$row['time_limit']."\n";
                         $row['remain_limit'].="total remain count: ".$row['count_remain']."/".$row['count_limit']."\n";
                         $row['remain_limit'].="total remain no connected count: ".$row['no_connected_remain']."/".$row['no_connected_limit']."\n";
+			$row['remain_limit'].="total remain SMS: ".$row['remain_sms']."/".$row['limit_sms']."\n";
 			$row['remain_limit'].="period remain time: ".$row['period_time_remain']."\n";
-			$row['remain_limit'].="period remain count: ".$row['period_count_remain']."";
+			$row['remain_limit'].="period remain count: ".$row['period_count_remain']."\n";
+			$row['remain_limit'].="period remain SMS: ".$row['period_remain_sms']."\n";
+			$row['remain_limit'].="month remain time: ".$row['month_remain_time']."";
 			
 			$row['limit_title']="no ring consecutive count: ".$row['no_ring_remain']."/".$row['no_ring_limit']."\n";
 			$row['limit_title'].="no answer consecutive count: ".$row['no_answer_remain']."/".$row['no_answer_limit']."\n";
 			$row['limit_title'].="short call consecutive count: ".$row['short_call_remain']."/".$row['short_call_limit']."";
 			
 			$row['remain_state'] = '<font color="#00FF00">Enough</font>';
-			if($row['remain_time']==0 || $row['period_time_remain']==0 || $row['period_count_remain']==0 || $row['count_remain']==0 || $row['no_connected_remain']==0){
+			if($row['remain_time']==0 || $row['period_time_remain']==0 || $row['period_count_remain']==0 || $row['count_remain']==0 || $row['no_connected_remain']==0 || $row['remain_sms']==0 || $row['period_remain_sms']==0  || $row['month_remain_time']==0){
 				$row['remain_state'] = '<font color="#FF0000">Exhaust</font>';
 			}
-			else if(($row['remain_time']<=$limit_t_w && $row['remain_time']!=-1) || ($row['period_time_remain']<=$limit_t_w && $row['period_time_remain']!=-1)|| ($row['period_count_remain']<=$limit_c_w && $row['period_count_remain']!=-1) || ($row['count_remain']<=$limit_c_w && $row['count_remain']!=-1) || ($row['no_connected_remain']<=$limit_c_w && $row['no_connected_remain']!=-1)){
+			else if(($row['remain_time']<=$limit_t_w && $row['remain_time']!=-1) || ($row['period_time_remain']<=$limit_t_w && $row['period_time_remain']!=-1)|| ($row['period_count_remain']<=$limit_c_w && $row['period_count_remain']!=-1) || ($row['count_remain']<=$limit_c_w && $row['count_remain']!=-1) || ($row['no_connected_remain']<=$limit_c_w && $row['no_connected_remain']!=-1) || ($row['remain_sms']<=$limit_c_w && $row['remain_sms']!=-1) || ($row['period_remain_sms']<=$limit_c_w && $row['period_remain_sms']!=-1) || ($row['month_remain_time']<=$limit_t_w && $row['month_remain_time']!=-1)){
 				$row['remain_state'] = '<font color="#FF8000">Warning</font>';
 			}
 			$row['limit_state'] = '<font color="#00FF00">Enough</font>';
@@ -437,7 +497,6 @@ if(isset($_GET['action'])) {
 			$rsdb[]=$row;
 			$strs[]=$row['sim_name'];
 			//$bank_db[bank_name]=$row[bank_name];
-			
 		}
 		
 		$bank_select="<select name=\"name\"  style=\"width:80px\" onchange=\"javascript:window.location='?bank_name='+this.options[this.selectedIndex].value+'&group_id=$_REQUEST[group_id]'\">\n\t<option value=\"0\">All</option>\n";
@@ -480,8 +539,7 @@ if(isset($_GET['action'])) {
                                 if(!empty($_POST["Id$i"])){
                                         $strs0[]=$_POST["Id$i"];
                                 }
-                        }       
-                        
+                        }
                 }else {
                         $nrcount=0;
                         $rsdblen=count($rsdb);
