@@ -362,7 +362,69 @@
 	@$db->updatequery("ALTER TABLE  `sim` ADD  `count_limit_no_connect` BOOL NOT NULL");
 /*1.7.2 fixed bug of set fixed IMEI*/
 /*1.7.2-t add dial api*/
+	@$db->updatequery("ALTER TABLE  `call_record` ADD  `type` int(1) NOT NULL");
+	if(!$rs || $rs[0] < 111){
+		@$db->updatequery("ALTER TABLE `call_record` ADD INDEX (`type`)");
+		@$db->updatequery("update `system` set `version`='111'");
+	}
+/*1.8 add limit sms*/
+	@$db->updatequery("ALTER TABLE  `sim` ADD `limit_sms` int(11) NOT NULL default '-1'");
+	@$db->updatequery("ALTER TABLE  `sim` ADD `remain_sms` int(11) NOT NULL default '-1'");
+	@$db->updatequery("ALTER TABLE  `sim` ADD `period_remain_sms` int(11) NOT NULL default '-1'");
+	if(!$rs || $rs[0] < 112){
+		$query=@$db->updatequery("select period_limit,id from sim where 1");
+		while($row=$db->fetch_array($query)){
+			if($row['period_limit']){
+				$limit_all="";
+				$a=explode(";", $row['period_limit']);
+				foreach($a as $limit){ //each period
+					if(strlen($limit ))$limit_all.=$limit.",-1;";
+				}
+				//echo "update sim set period_limit='".$limit_all."' where id=$row[id]";
+				if(strlen($limit_all)) @$db->updatequery("update sim set period_limit='".$limit_all."' where id=$row[id]");
+			}
+		}
+		
+		@$db->updatequery("update `system` set `version`='112'");
+	}
 
+
+/*
+	for($i=1;$i<=100;$i++){
+			$name="dbl".$i;
+                        $db->query("INSERT INTO `sim_team` (sim_team_name) value ('$name') ");
+                        $groupiddb=$db->fetch_array($db->query("SELECT LAST_INSERT_ID()"));
+                        $groupid=$groupiddb[0];
+                        $db->query("INSERT INTO `scheduler` (name,group_id,type) value ('$name', '$groupid','cycle') ");
+                        $schiddb=$db->fetch_array($db->query("SELECT LAST_INSERT_ID()"));
+                        $schid=$schiddb[0];
+                        $db->query("update sim_team set scheduler_id='$schid' where sim_team_id='$groupid'");
+	}
+*/
+/*1.8.1-t1 disable select auto dial*/
+/*1.9 add count no connected call, disable call logs*/
+/*1.9.1 add fd limit*/
+
+/*1.9.2 add imei_imsi file*/
+        if(!$rs || $rs[0] < 113){
+                @$db->updatequery("ALTER TABLE `imei_db` ADD UNIQUE ( `imei` ) ");
+                @$db->updatequery("update `system` set `version`='113'");
+        }
+	@$db->updatequery("ALTER TABLE `sim` ADD `month_remain_time` INT NOT NULL DEFAULT '-1'");
+	@$db->updatequery("ALTER TABLE `sim` ADD `month_limit_time` INT NOT NULL DEFAULT '-1'");
+	@$db->updatequery("ALTER TABLE `sim` ADD `month_reset_day` INT NOT NULL DEFAULT '1'");
+	@$db->updatequery("ALTER TABLE `sim` ADD `month_last_reset_time` timestamp NOT NULL default CURRENT_TIMESTAMP");
+/* 1.10-t1 set IMEI befor bind when IMEI MODE=IMEI-IMSI datebase */
+/* 1.10-t2 add simnum*/
+	@$db->updatequery("ALTER TABLE `sim` ADD `simnum` VARCHAR( 32 ) NOT NULL");
+/* 1.10-t3 fixed bug of dial in api.php */
+/* 1.11 fixed bug of period time*/
+/* 1.12 remove &$ */
+/* 1.13 fixed bug of 1.11 */
+/* 1.14 fixed bug of month remain time*/
+/* 1.15 fixed bug of include excel class */
+/* 1.16 fixed bug of remain count when add  */
+/* 1.17-t fixed bug of period time reset  */
 	echo "update done! <a href=''  target=_top>Return</a>";
 
 ?>
